@@ -17,7 +17,7 @@
 
 """ Expose package-wide elements. """
 
-__version__ = "1.4.1"
+__version__ = "1.8.0"
 """ Examples of valid version strings according :pep:`440#version-scheme`:
 
 .. code-block:: python
@@ -29,3 +29,14 @@ __version__ = "1.4.1"
     __version__ = '1.2.3'        # Final Release
     __version__ = '1.2.3.post1'  # Post Release 1
 """
+
+
+# Import all click's module-level content to allow for drop-in replacement.
+from click import *
+
+# Overrides some of click helpers with cloup's.
+from cloup import argument, option, option_group
+
+# Replace some of click defaults with click-extra variant.
+from .colorize import version_option
+from .commands import command, group
